# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.with_limits import WithLimits

class TestWithLimits(unittest.TestCase):
    """WithLimits unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WithLimits:
        """Test WithLimits
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WithLimits`
        """
        model = WithLimits()
        if include_optional:
            return WithLimits(
                account_limits = 56,
                applies_to = '',
                block = True,
                consumption = 1,
                id = 56,
                limits = 56,
                reference_id = 56,
                reference_type = 'SUBSCRIPTION',
                remaining = 56,
                resets_in_seconds = 56,
                subscription_limits = 56
            )
        else:
            return WithLimits(
                applies_to = '',
        )
        """

    def testWithLimits(self):
        """Test WithLimits"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.scope import Scope

class TestScope(unittest.TestCase):
    """Scope unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testScope(self):
        """Test Scope"""
        # inst = Scope()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Middleware

    Knowledge Graph data management.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from wordlift_client.models.html import Html
from typing import Optional, Set
from typing_extensions import Self

class Request3(BaseModel):
    """
    The request
    """ # noqa: E501
    html: Optional[Html] = None
    url: Optional[StrictStr] = Field(default=None, description="The url of the page to analyze.")
    url_client: Optional[StrictStr] = Field(default=None, description="The client which the analysis should use to extract the content, by default chrome is used.", alias="urlClient")
    language: Annotated[str, Field(min_length=2, strict=True, max_length=2)] = Field(description="The content language, 2 letters code, e.g. 'en'.")
    text: Optional[StrictStr] = Field(default=None, description="A textual fragment.")
    exclude: Optional[List[StrictStr]] = Field(default=None, description="An array of item IDs to exclude from the analysis results.")
    scope: StrictStr = Field(description="The scope of the analysis, one of 'local', 'network', 'cloud-only', 'network-only' or 'all'.")
    matches: Optional[StrictInt] = Field(default=None, description="Filter out results that don't have at least the specified number of occurrences. By default 1.")
    links: Optional[StrictStr] = Field(default=None, description="When returning an interpolated HTML results, matches should have the 'wl-link' class. By default 'no'.")
    __properties: ClassVar[List[str]] = ["html", "url", "urlClient", "language", "text", "exclude", "scope", "matches", "links"]

    @field_validator('url_client')
    def url_client_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['CHROME', 'PLAIN_HTTP', 'CHROME, PLAIN_HTTP']):
            raise ValueError("must be one of enum values ('CHROME', 'PLAIN_HTTP', 'CHROME, PLAIN_HTTP')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Request3 from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of html
        if self.html:
            _dict['html'] = self.html.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Request3 from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "html": Html.from_dict(obj["html"]) if obj.get("html") is not None else None,
            "url": obj.get("url"),
            "urlClient": obj.get("urlClient"),
            "language": obj.get("language"),
            "text": obj.get("text"),
            "exclude": obj.get("exclude"),
            "scope": obj.get("scope"),
            "matches": obj.get("matches"),
            "links": obj.get("links")
        })
        return _obj





# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.active_account import ActiveAccount

class TestActiveAccount(unittest.TestCase):
    """ActiveAccount unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ActiveAccount:
        """Test ActiveAccount
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ActiveAccount`
        """
        model = ActiveAccount()
        if include_optional:
            return ActiveAccount(
                country = '',
                diagnostic_plugins = [
                    wordlift_client.models.diagnostic_plugin.DiagnosticPlugin(
                        account_id = 56, 
                        active = True, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = 56, 
                        name = '', 
                        version = '', )
                    ],
                domain_uri = '',
                google_search_console_site_url = '',
                id = 56,
                is_wordpress = True,
                key = '',
                language = '',
                ng_dataset_id = '',
                package_type = '',
                subscription = wordlift_client.models.account_subscription.AccountSubscription(
                    email = '', 
                    first_name = '', 
                    last_name = '', 
                    order_id = 56, 
                    sku = '', ),
                subscription_id = 56,
                total_entities = 56,
                total_entities_with_schema_url = 56,
                url = '',
                user_id = 56,
                wp_admin = '',
                wp_include_exclude_default = '',
                wp_json = ''
            )
        else:
            return ActiveAccount(
        )
        """

    def testActiveAccount(self):
        """Test ActiveAccount"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Middleware

    Knowledge Graph data management.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr
from typing import Any, Dict
from typing_extensions import Annotated

from wordlift_client.api_client import ApiClient, RequestSerialized
from wordlift_client.api_response import ApiResponse
from wordlift_client.rest import RESTResponseType


class MicrodataApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    async def microdata_to_json_ld(
        self,
        u: Annotated[StrictStr, Field(description="The web page URL")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Dict[str, object]:
        """Microdata to JSON-LD

        Provided a URL, converts any microdata found on that URL to JSON-LD.

        :param u: The web page URL (required)
        :type u: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._microdata_to_json_ld_serialize(
            u=u,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Dict[str, object]",
            '401': None,
            '500': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def microdata_to_json_ld_with_http_info(
        self,
        u: Annotated[StrictStr, Field(description="The web page URL")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Dict[str, object]]:
        """Microdata to JSON-LD

        Provided a URL, converts any microdata found on that URL to JSON-LD.

        :param u: The web page URL (required)
        :type u: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._microdata_to_json_ld_serialize(
            u=u,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Dict[str, object]",
            '401': None,
            '500': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def microdata_to_json_ld_without_preload_content(
        self,
        u: Annotated[StrictStr, Field(description="The web page URL")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Microdata to JSON-LD

        Provided a URL, converts any microdata found on that URL to JSON-LD.

        :param u: The web page URL (required)
        :type u: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._microdata_to_json_ld_serialize(
            u=u,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Dict[str, object]",
            '401': None,
            '500': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _microdata_to_json_ld_serialize(
        self,
        u,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if u is not None:
            
            _query_params.append(('u', u))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/ld+json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/microdata-to-jsonld',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.classification_request import ClassificationRequest

class TestClassificationRequest(unittest.TestCase):
    """ClassificationRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClassificationRequest:
        """Test ClassificationRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClassificationRequest`
        """
        model = ClassificationRequest()
        if include_optional:
            return ClassificationRequest(
                classes = ["indian","thai","chinese","italian"],
                text = 'This dish is a deli egg-bacon-and-cheese-on-a-roll that has been pasta-fied, fancified, fetishized and turned into an Italian tradition that, like many inviolate Italian traditions, is actually far less old than the Mayflower.'
            )
        else:
            return ClassificationRequest(
        )
        """

    def testClassificationRequest(self):
        """Test ClassificationRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.content_generation_word_biases_api import ContentGenerationWordBiasesApi


class TestContentGenerationWordBiasesApi(unittest.TestCase):
    """ContentGenerationWordBiasesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ContentGenerationWordBiasesApi()

    def tearDown(self) -> None:
        pass

    def test_create_word(self) -> None:
        """Test case for create_word

        Create
        """
        pass

    def test_create_words(self) -> None:
        """Test case for create_words

        Update for prompt
        """
        pass

    def test_create_words_from_csv(self) -> None:
        """Test case for create_words_from_csv

        Update from CSV
        """
        pass

    def test_delete_word(self) -> None:
        """Test case for delete_word

        Delete
        """
        pass

    def test_list_words(self) -> None:
        """Test case for list_words

        List
        """
        pass

    def test_update_word(self) -> None:
        """Test case for update_word

        Update
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.rule_request import RuleRequest

class TestRuleRequest(unittest.TestCase):
    """RuleRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RuleRequest:
        """Test RuleRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RuleRequest`
        """
        model = RuleRequest()
        if include_optional:
            return RuleRequest(
                description = '',
                fixes = [
                    wordlift_client.models.validation_fix.ValidationFix(
                        type = 'FIND_AND_REPLACE', 
                        what = '', 
                        with = '', )
                    ],
                is_enabled = True,
                level = 'RECOMMENDED',
                name = '',
                project_id = 56,
                project_type = 'SMART_CONTENT',
                scope = 'USER',
                type = '',
                what_operand_lhs = 'EVERYWHERE',
                what_operand_rhs = '',
                what_operator = 'CONTAINS',
                when_operand_lhs = '',
                when_operand_rhs = '',
                when_operator = 'ALWAYS'
            )
        else:
            return RuleRequest(
                level = 'RECOMMENDED',
                name = '',
                scope = 'USER',
                type = '',
                what_operand_lhs = 'EVERYWHERE',
                what_operand_rhs = '',
                what_operator = 'CONTAINS',
                when_operand_lhs = '',
                when_operand_rhs = '',
                when_operator = 'ALWAYS',
        )
        """

    def testRuleRequest(self):
        """Test RuleRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
